@@ -1702,15 +1702,14 @@ drag_data_received  (GtkWidget *widget, GdkDragContext *context,
         
         str = gtk_selection_data_get_text (selection_data);
 
-        /* FIXME should this be converted back to locale encoding
-         * before sending to the terminal? Most likely yes.
+        /*
+	 * pass UTF-8 to the terminal widget. The terminal widget
+	 * should know which encoding mode it's in and be able
+	 * to perform the correct conversion.
          */
         if (str && *str)
-          {
-            terminal_widget_write_data_to_child (screen->priv->term,
-                                                 str, strlen (str));
-          }
-
+	  terminal_widget_write_data_to_child (screen->priv->term,
+					       str, strlen (str));
         g_free (str);
       }
       break;
@@ -2144,8 +2143,6 @@ make_font_monospace (const PangoFontDescription *font)
 {
   PangoFontDescription *ret;
 
-  return NULL;
-  
   ret = pango_font_description_copy (font);
 
   /* FIXME */
