@@ -127,6 +127,8 @@ static void parse_options_callback (poptContext              ctx,
                                     const struct poptOption *opt,
                                     const char              *arg,
                                     void                    *data);
+static void client_die_cb          (GnomeClient             *client,
+                                    gpointer                 data);
 
 enum {
   OPTION_COMMAND = 1,
@@ -656,12 +658,10 @@ parse_options_callback (poptContext              ctx,
     {
     case OPTION_COMMAND:
       {
-        const char *arg;
         GError *err;
         InitialTab *it;
         char **exec_argv;
             
-        arg = poptGetOptArg (ctx);
 
         if (arg == NULL)
           {
@@ -718,17 +718,15 @@ parse_options_callback (poptContext              ctx,
     case OPTION_WINDOW_WITH_PROFILE_ID:
       {
         InitialWindow *iw;
-        const char *prof;
 
-        prof = poptGetOptArg (ctx);
 
-        if (prof == NULL)
+        if (arg == NULL)
           {
             g_printerr (_("Option --window-with-profile requires an argument specifying what profile to use\n"));
             exit (1);
           }
 
-        iw = add_new_window (results, prof,
+        iw = add_new_window (results, arg,
                              opt->val == OPTION_WINDOW_WITH_PROFILE_ID);
       }
       break;
@@ -737,11 +735,9 @@ parse_options_callback (poptContext              ctx,
     case OPTION_TAB_WITH_PROFILE_ID:
       {
         InitialWindow *iw;
-        const char *prof;
 
-        prof = poptGetOptArg (ctx);
 
-        if (prof == NULL)
+        if (arg == NULL)
           {
             g_printerr (_("Option --tab-with-profile requires an argument specifying what profile to use\n"));
             exit (1);
@@ -753,12 +749,12 @@ parse_options_callback (poptContext              ctx,
             iw = g_list_last (results->initial_windows)->data;
 
             iw->tabs = g_list_append (iw->tabs,
-                                      initial_tab_new (prof,
+                                      initial_tab_new (arg,
                                                        opt->val == OPTION_TAB_WITH_PROFILE_ID));
           }
         else
           {
-            iw = add_new_window (results, prof, 
+            iw = add_new_window (results, arg, 
                                  opt->val == OPTION_TAB_WITH_PROFILE_ID);
           }
       }
@@ -819,11 +815,9 @@ parse_options_callback (poptContext              ctx,
     case OPTION_GEOMETRY:
       {
         InitialWindow *iw;
-        const char *geometry;
 
-        geometry = poptGetOptArg (ctx);
 
-        if (geometry == NULL)
+        if (arg == NULL)
           {
             g_printerr (_("Option --geometry requires an argument giving the geometry\n"));
             exit (1);
@@ -838,7 +832,7 @@ parse_options_callback (poptContext              ctx,
                 exit (1);
               }
 
-            iw->geometry = g_strdup (geometry);
+            iw->geometry = g_strdup (arg);
           }
         else
           {
@@ -849,7 +843,7 @@ parse_options_callback (poptContext              ctx,
               }
             else
               {
-                results->default_geometry = g_strdup (geometry);
+                results->default_geometry = g_strdup (arg);
               }
           }
       }
@@ -861,12 +855,10 @@ parse_options_callback (poptContext              ctx,
 
     case OPTION_TITLE:
       {
-        const char *title;
         InitialTab *it;
             
-        title = poptGetOptArg (ctx);
 
-        if (title == NULL)
+        if (arg == NULL)
           {
             g_printerr (_("Option --title requires an argument giving the title\n"));
             exit (1);
@@ -880,18 +872,16 @@ parse_options_callback (poptContext              ctx,
             exit (1);
           }
 
-        it->title = g_strdup (title);
+        it->title = g_strdup (arg);
       }
       break;
 
     case OPTION_WORKING_DIRECTORY:
       {
-        const char *dir;
         InitialTab *it;
             
-        dir = poptGetOptArg (ctx);
 
-        if (dir == NULL)
+        if (arg == NULL)
           {
             g_printerr (_("Option --working-directory requires an argument giving the directory\n"));
             exit (1);
@@ -905,7 +895,7 @@ parse_options_callback (poptContext              ctx,
             exit (1);
           }
 
-        it->working_dir = g_strdup (dir);
+        it->working_dir = g_strdup (arg);
       }
       break;
 
@@ -1197,6 +1187,11 @@ main (int argc, char **argv)
                     G_CALLBACK (save_yourself_callback),
                     app);
 
+  g_signal_connect (G_OBJECT (sm_client), "die",
+                    G_CALLBACK (client_die_cb),
+                    NULL);
+
+
   if (new_terminal_with_options (results))
     return 1;
 
@@ -2787,6 +2782,12 @@ save_yourself_callback (GnomeClient        *client,
   return TRUE;
 }
 
+static void
+client_die_cb (GnomeClient        *client,
+               gpointer            data)
+{
+  gtk_main_quit ();
+}
 
 /*
  * Utility stuff
